type token =
  | IDENTIFIER of (string)
  | STRING_LITERAL of (string)
  | TYPENAME of (string)
  | CONSTANT of (Clogic.constant)
  | LPAR
  | RPAR
  | IF
  | ELSE
  | COLON
  | COLONCOLON
  | DOT
  | DOTDOT
  | AMP
  | INT
  | FLOAT
  | LT
  | GT
  | LE
  | GE
  | EQ
  | NE
  | COMMA
  | ARROW
  | EQUAL
  | FORALL
  | EXISTS
  | IFF
  | IMPLIES
  | AND
  | OR
  | NOT
  | TRUE
  | FALSE
  | OLD
  | AT
  | RESULT
  | BLOCK_LENGTH
  | BASE_ADDR
  | SEPARATED
  | FULLSEPARATED
  | VALID
  | VALID_INDEX
  | VALID_RANGE
  | FRESH
  | THEN
  | QUESTION
  | MINUS
  | PLUS
  | STAR
  | SLASH
  | PERCENT
  | LSQUARE
  | RSQUARE
  | EOF
  | INVARIANT
  | VARIANT
  | DECREASES
  | FOR
  | LABEL
  | ASSERT
  | SEMICOLON
  | NULL
  | REQUIRES
  | ENSURES
  | ASSIGNS
  | LOOP_ASSIGNS
  | NOTHING
  | READS
  | LOGIC
  | PREDICATE
  | AXIOM
  | LBRACE
  | RBRACE
  | GHOST
  | SET
  | VOID
  | CHAR
  | SIGNED
  | UNSIGNED
  | SHORT
  | LONG
  | DOUBLE
  | STRUCT
  | ENUM
  | UNION

open Parsing;;
# 20 "c/clparser.mly"
  open Ctypes
  open Cast
  open Clogic

  let loc () = (symbol_start (), symbol_end ())
  let loc_i i = (rhs_start i, rhs_end i)
  let info x = { Clogic.lexpr_node = x; lexpr_loc = loc () }

  type ghost_decl =
    | Dsimple 
    | Darray of ghost_decl * lexpr option

  let rec expr_of_lexpr e =
    match e.lexpr_node with
      | PLconstant c -> 
	  { Cast.node = Cast.CEconstant c ; Cast.loc = e.lexpr_loc }
      | _ -> Creport.error e.lexpr_loc "not a constant"

  let option_app f = function None -> None | Some x -> Some (f x)

  let rec ghost_type ty gd =
    match gd with
      | Dsimple -> ty
      | Darray(gd,size) -> 
	    Cast_misc.noattr 
	      (Cast.CTarray (ghost_type ty gd, option_app expr_of_lexpr size))

  let ghost ty (id,gd,cinit) =
    let gty = ghost_type ty gd in
    LDghost(gty,id,cinit)
    
    
# 123 "c/clparser.ml"
let yytransl_const = [|
  261 (* LPAR *);
  262 (* RPAR *);
  263 (* IF *);
  264 (* ELSE *);
  265 (* COLON *);
  266 (* COLONCOLON *);
  267 (* DOT *);
  268 (* DOTDOT *);
  269 (* AMP *);
  270 (* INT *);
  271 (* FLOAT *);
  272 (* LT *);
  273 (* GT *);
  274 (* LE *);
  275 (* GE *);
  276 (* EQ *);
  277 (* NE *);
  278 (* COMMA *);
  279 (* ARROW *);
  280 (* EQUAL *);
  281 (* FORALL *);
  282 (* EXISTS *);
  283 (* IFF *);
  284 (* IMPLIES *);
  285 (* AND *);
  286 (* OR *);
  287 (* NOT *);
  288 (* TRUE *);
  289 (* FALSE *);
  290 (* OLD *);
  291 (* AT *);
  292 (* RESULT *);
  293 (* BLOCK_LENGTH *);
  294 (* BASE_ADDR *);
  295 (* SEPARATED *);
  296 (* FULLSEPARATED *);
  297 (* VALID *);
  298 (* VALID_INDEX *);
  299 (* VALID_RANGE *);
  300 (* FRESH *);
  301 (* THEN *);
  302 (* QUESTION *);
  303 (* MINUS *);
  304 (* PLUS *);
  305 (* STAR *);
  306 (* SLASH *);
  307 (* PERCENT *);
  308 (* LSQUARE *);
  309 (* RSQUARE *);
    0 (* EOF *);
  310 (* INVARIANT *);
  311 (* VARIANT *);
  312 (* DECREASES *);
  313 (* FOR *);
  314 (* LABEL *);
  315 (* ASSERT *);
  316 (* SEMICOLON *);
  317 (* NULL *);
  318 (* REQUIRES *);
  319 (* ENSURES *);
  320 (* ASSIGNS *);
  321 (* LOOP_ASSIGNS *);
  322 (* NOTHING *);
  323 (* READS *);
  324 (* LOGIC *);
  325 (* PREDICATE *);
  326 (* AXIOM *);
  327 (* LBRACE *);
  328 (* RBRACE *);
  329 (* GHOST *);
  330 (* SET *);
  331 (* VOID *);
  332 (* CHAR *);
  333 (* SIGNED *);
  334 (* UNSIGNED *);
  335 (* SHORT *);
  336 (* LONG *);
  337 (* DOUBLE *);
  338 (* STRUCT *);
  339 (* ENUM *);
  340 (* UNION *);
    0|]

let yytransl_block = [|
  257 (* IDENTIFIER *);
  258 (* STRING_LITERAL *);
  259 (* TYPENAME *);
  260 (* CONSTANT *);
    0|]

let yylhs = "\255\255\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\005\000\005\000\008\000\008\000\
\008\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
\007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
\007\000\007\000\007\000\007\000\007\000\007\000\009\000\009\000\
\003\000\003\000\003\000\003\000\003\000\003\000\006\000\006\000\
\010\000\010\000\011\000\011\000\012\000\012\000\013\000\016\000\
\016\000\016\000\016\000\017\000\019\000\019\000\015\000\015\000\
\001\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
\024\000\014\000\014\000\014\000\018\000\018\000\020\000\020\000\
\025\000\025\000\026\000\022\000\022\000\022\000\022\000\022\000\
\022\000\022\000\023\000\028\000\028\000\028\000\028\000\027\000\
\027\000\004\000\004\000\030\000\030\000\029\000\029\000\031\000\
\031\000\032\000\034\000\034\000\034\000\033\000\033\000\033\000\
\035\000\035\000\000\000"

let yylen = "\002\000\
\003\000\003\000\003\000\003\000\002\000\001\000\001\000\003\000\
\006\000\004\000\004\000\006\000\006\000\004\000\006\000\008\000\
\004\000\001\000\001\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\004\000\006\000\002\000\002\000\002\000\002\000\
\005\000\004\000\006\000\004\000\004\000\001\000\003\000\001\000\
\004\000\004\000\004\000\003\000\000\000\001\000\001\000\002\000\
\001\000\001\000\001\000\002\000\002\000\002\000\001\000\002\000\
\002\000\001\000\002\000\002\000\001\000\002\000\003\000\002\000\
\003\000\001\000\001\000\002\000\001\000\002\000\001\000\002\000\
\001\000\001\000\001\000\001\000\001\000\001\000\000\000\001\000\
\001\000\003\000\000\000\002\000\000\000\002\000\004\000\003\000\
\002\000\002\000\001\000\002\000\004\000\002\000\000\000\002\000\
\002\000\001\000\001\000\001\000\001\000\002\000\002\000\004\000\
\001\000\000\000\002\000\002\000\000\000\001\000\002\000\002\000\
\001\000\003\000\001\000\006\000\008\000\005\000\007\000\008\000\
\004\000\004\000\003\000\001\000\001\000\001\000\001\000\000\000\
\001\000\001\000\003\000\002\000\004\000\001\000\003\000\001\000\
\003\000\001\000\001\000\004\000\003\000\001\000\003\000\004\000\
\001\000\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\147\000\000\000\100\000\101\000\
\000\000\000\000\000\000\000\000\098\000\099\000\000\000\019\000\
\000\000\000\000\000\000\000\000\000\000\000\000\006\000\007\000\
\000\000\000\000\038\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\018\000\000\000\
\103\000\000\000\000\000\000\000\112\000\000\000\111\000\000\000\
\000\000\069\000\055\000\066\000\050\000\051\000\000\000\000\000\
\058\000\000\000\067\000\000\000\000\000\000\000\000\000\125\000\
\126\000\124\000\127\000\000\000\000\000\000\000\000\000\000\000\
\000\000\110\000\000\000\089\000\097\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\073\000\
\074\000\075\000\076\000\077\000\078\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\071\000\000\000\054\000\052\000\057\000\
\000\000\056\000\053\000\059\000\000\000\064\000\068\000\070\000\
\000\000\000\000\000\000\139\000\000\000\134\000\000\000\000\000\
\000\000\108\000\107\000\000\000\000\000\088\000\000\000\000\000\
\000\000\080\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\026\000\025\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\114\000\072\000\063\000\065\000\
\000\000\129\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\087\000\000\000\000\000\041\000\000\000\000\000\
\000\000\000\000\000\000\131\000\000\000\034\000\000\000\037\000\
\036\000\000\000\000\000\014\000\000\000\000\000\017\000\000\000\
\027\000\000\000\000\000\000\000\135\000\000\000\000\000\137\000\
\141\000\000\000\096\000\093\000\082\000\000\000\133\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\145\000\000\000\140\000\000\000\035\000\012\000\
\013\000\015\000\000\000\028\000\000\000\119\000\000\000\000\000\
\143\000\000\000\117\000\120\000\144\000\146\000\016\000"

let yydgoto = "\002\000\
\013\000\054\000\130\000\202\000\195\000\161\000\068\000\094\000\
\133\000\162\000\014\000\157\000\015\000\080\000\211\000\016\000\
\017\000\018\000\084\000\019\000\020\000\021\000\022\000\078\000\
\055\000\056\000\203\000\076\000\149\000\095\000\150\000\151\000\
\240\000\152\000\004\001"

let yysindex = "\040\000\
\102\255\000\000\162\006\041\255\211\006\211\006\066\005\031\255\
\046\255\047\255\001\255\211\006\000\000\242\254\000\000\000\000\
\245\254\007\255\000\000\076\000\000\000\000\000\018\255\000\000\
\054\255\211\006\211\006\031\255\031\255\211\006\000\000\000\000\
\076\255\078\255\000\000\079\255\094\255\099\255\100\255\109\255\
\113\255\114\255\115\255\211\006\211\006\211\006\000\000\082\010\
\000\000\026\255\082\010\082\010\000\000\082\010\000\000\101\255\
\072\255\000\000\000\000\000\000\000\000\000\000\251\254\037\255\
\000\000\215\254\000\000\073\255\124\255\121\255\118\255\000\000\
\000\000\000\000\000\000\127\255\082\010\116\255\025\006\074\255\
\007\255\000\000\211\006\000\000\000\000\211\006\211\006\211\006\
\207\255\015\255\110\009\014\255\082\255\137\255\117\255\083\255\
\138\010\211\006\211\006\211\006\211\006\211\006\211\006\211\006\
\211\006\211\006\211\006\014\255\014\255\014\255\143\255\000\000\
\000\000\000\000\000\000\000\000\000\000\144\255\211\006\211\006\
\211\006\211\006\211\006\211\006\211\006\211\006\211\006\211\006\
\211\006\211\006\211\006\000\000\097\255\000\000\000\000\000\000\
\067\255\000\000\000\000\000\000\068\255\000\000\000\000\000\000\
\145\255\031\255\211\006\000\000\129\255\000\000\125\255\105\255\
\211\006\000\000\000\000\211\006\096\255\000\000\039\007\152\009\
\148\255\000\000\082\010\082\010\004\007\211\006\211\006\211\006\
\106\255\031\255\211\006\086\007\167\009\133\007\180\007\209\009\
\224\009\227\007\010\010\025\010\018\008\000\000\000\000\082\010\
\082\010\138\010\124\010\010\009\130\255\130\255\014\255\014\255\
\014\255\052\009\147\255\249\255\000\000\000\000\000\000\000\000\
\031\255\000\000\157\255\082\010\127\255\182\005\112\006\082\010\
\082\010\007\255\000\000\168\255\211\006\000\000\014\255\014\255\
\251\008\082\010\120\255\000\000\082\010\000\000\176\255\000\000\
\000\000\211\006\211\006\000\000\211\006\211\006\000\000\211\006\
\000\000\211\006\178\255\238\254\000\000\182\005\082\010\000\000\
\000\000\067\009\000\000\000\000\000\000\211\006\000\000\183\255\
\065\008\112\008\159\008\067\010\138\010\082\010\135\255\139\255\
\211\006\211\006\000\000\254\254\000\000\138\010\000\000\000\000\
\000\000\000\000\211\006\000\000\211\006\000\000\060\006\161\255\
\000\000\206\008\000\000\000\000\000\000\000\000\000\000"

let yyrindex = "\000\000\
\033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\044\000\000\000\000\000\
\008\000\000\000\012\000\000\000\000\000\000\000\007\005\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\005\000\
\000\000\001\000\183\000\038\000\000\000\100\000\000\000\043\000\
\190\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\016\255\000\000\041\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\187\255\000\000\000\000\003\000\
\207\000\000\000\000\000\000\000\000\000\206\255\000\000\000\000\
\000\000\000\000\000\000\124\000\000\000\000\000\013\255\000\000\
\098\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\185\000\246\000\055\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\202\255\000\000\000\000\000\000\214\255\000\000\000\000\000\000\
\023\255\000\000\000\000\000\000\029\255\000\000\000\000\000\000\
\000\000\210\255\000\000\000\000\217\000\000\000\011\000\010\000\
\000\000\000\000\000\000\000\000\219\000\000\000\220\000\215\255\
\000\000\000\000\229\000\116\004\063\000\000\000\000\000\000\000\
\252\254\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\121\004\
\183\004\163\003\091\004\000\000\171\002\232\002\117\001\178\001\
\239\001\219\255\000\000\037\003\000\000\000\000\000\000\000\000\
\210\255\000\000\000\000\238\000\000\000\000\000\000\000\239\000\
\006\000\000\000\000\000\000\000\000\000\000\000\044\002\109\002\
\000\000\188\004\000\000\000\000\213\004\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\188\255\000\000\240\000\000\000\000\000\004\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\225\003\189\255\000\000\243\000\
\000\000\000\000\000\000\000\000\000\000\030\004\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\038\006\000\000\241\255\013\000\000\000\223\000\236\000\
\000\000\032\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\232\000\182\255\233\000\000\000\000\000\000\000\000\000\
\177\255\000\000\050\000\000\000\000\000\000\000\047\000\000\000\
\044\255\000\000\000\000"

let yytablesize = 3006
let yytable = "\155\000\
\040\000\132\000\085\000\142\000\092\000\086\000\158\000\109\000\
\134\000\138\000\136\000\091\000\093\000\096\000\072\000\073\000\
\061\000\132\000\130\000\016\001\166\000\061\000\086\000\060\000\
\111\000\003\001\087\000\088\000\060\000\062\000\086\000\057\000\
\083\000\058\000\062\000\088\000\118\000\084\000\142\000\143\000\
\001\000\049\000\113\000\106\000\059\000\060\000\070\000\071\000\
\001\001\079\000\138\000\197\000\002\001\007\000\050\000\132\000\
\058\000\024\000\025\000\022\001\026\000\083\000\039\000\144\000\
\061\000\129\000\027\000\059\000\060\000\017\001\135\000\060\000\
\130\000\136\000\137\000\085\000\074\000\062\000\028\000\029\000\
\098\000\075\000\099\000\100\000\030\000\031\000\032\000\033\000\
\034\000\035\000\036\000\037\000\038\000\039\000\040\000\041\000\
\042\000\043\000\101\000\115\000\044\000\045\000\046\000\102\000\
\103\000\061\000\062\000\063\000\064\000\065\000\066\000\067\000\
\139\000\104\000\047\000\140\000\141\000\105\000\106\000\107\000\
\132\000\144\000\131\000\032\000\145\000\146\000\147\000\148\000\
\061\000\062\000\063\000\064\000\065\000\066\000\067\000\243\000\
\156\000\169\000\170\000\153\000\111\000\168\000\171\000\182\000\
\183\000\198\000\199\000\200\000\206\000\201\000\205\000\210\000\
\118\000\214\000\220\000\003\000\207\000\219\000\234\000\004\000\
\005\000\050\000\236\000\006\000\024\000\025\000\007\000\026\000\
\244\000\008\000\009\000\010\000\247\000\027\000\011\000\012\000\
\248\000\014\001\126\000\127\000\128\000\129\000\102\000\000\001\
\029\000\028\000\029\000\012\001\007\001\019\001\047\000\030\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\038\000\
\039\000\040\000\041\000\042\000\043\000\013\001\090\000\044\000\
\045\000\046\000\105\000\079\000\165\000\045\000\048\000\128\000\
\123\000\111\000\095\000\094\000\081\000\047\000\112\000\113\000\
\114\000\115\000\116\000\117\000\122\000\118\000\046\000\238\000\
\021\001\119\000\120\000\121\000\122\000\121\000\104\000\118\000\
\045\000\046\000\116\000\069\000\245\000\030\000\255\000\090\000\
\081\000\082\000\235\000\237\000\123\000\124\000\125\000\126\000\
\127\000\128\000\129\000\111\000\000\000\000\000\040\000\000\000\
\040\000\040\000\000\000\040\000\040\000\000\000\000\000\118\000\
\040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
\040\000\142\000\000\000\040\000\040\000\040\000\040\000\138\000\
\136\000\138\000\000\000\000\000\000\000\000\000\000\000\124\000\
\125\000\126\000\127\000\128\000\129\000\040\000\040\000\040\000\
\040\000\040\000\040\000\040\000\040\000\040\000\031\000\040\000\
\040\000\040\000\085\000\092\000\000\000\086\000\109\000\040\000\
\040\000\040\000\110\000\000\000\039\000\092\000\039\000\039\000\
\040\000\039\000\039\000\142\000\000\000\000\000\039\000\039\000\
\039\000\039\000\039\000\039\000\039\000\039\000\039\000\109\000\
\083\000\039\000\039\000\039\000\039\000\084\000\000\000\083\000\
\083\000\113\000\113\000\106\000\084\000\084\000\000\000\000\000\
\000\000\113\000\106\000\039\000\039\000\039\000\039\000\039\000\
\039\000\039\000\039\000\039\000\022\000\039\000\039\000\039\000\
\000\000\115\000\000\000\000\000\000\000\039\000\039\000\039\000\
\000\000\032\000\000\000\032\000\032\000\000\000\039\000\032\000\
\000\000\000\000\000\000\032\000\032\000\032\000\032\000\032\000\
\032\000\032\000\000\000\032\000\000\000\000\000\032\000\032\000\
\032\000\032\000\115\000\115\000\000\000\000\000\000\000\000\000\
\000\000\000\000\115\000\000\000\000\000\000\000\000\000\000\000\
\032\000\032\000\032\000\032\000\032\000\032\000\032\000\000\000\
\032\000\023\000\032\000\032\000\032\000\000\000\000\000\000\000\
\000\000\000\000\032\000\032\000\032\000\000\000\029\000\000\000\
\029\000\029\000\000\000\032\000\029\000\000\000\000\000\000\000\
\029\000\029\000\029\000\029\000\029\000\029\000\029\000\000\000\
\029\000\000\000\000\000\029\000\029\000\029\000\029\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\029\000\029\000\029\000\
\029\000\029\000\029\000\029\000\000\000\029\000\024\000\029\000\
\029\000\029\000\000\000\000\000\000\000\000\000\000\000\029\000\
\029\000\029\000\000\000\030\000\000\000\030\000\030\000\000\000\
\029\000\030\000\000\000\000\000\000\000\030\000\030\000\030\000\
\030\000\030\000\030\000\030\000\000\000\030\000\000\000\000\000\
\030\000\030\000\030\000\030\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\030\000\030\000\030\000\030\000\030\000\030\000\
\030\000\000\000\030\000\043\000\030\000\030\000\030\000\000\000\
\000\000\000\000\000\000\000\000\030\000\030\000\030\000\000\000\
\000\000\000\000\000\000\000\000\031\000\030\000\031\000\031\000\
\000\000\000\000\031\000\000\000\000\000\000\000\031\000\031\000\
\031\000\031\000\031\000\031\000\031\000\000\000\031\000\000\000\
\000\000\031\000\031\000\031\000\031\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\031\000\031\000\031\000\031\000\031\000\
\031\000\031\000\000\000\031\000\042\000\031\000\031\000\031\000\
\000\000\000\000\000\000\000\000\000\000\031\000\031\000\031\000\
\000\000\000\000\022\000\000\000\022\000\022\000\031\000\000\000\
\022\000\000\000\000\000\000\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\000\000\022\000\000\000\000\000\022\000\
\022\000\022\000\022\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
\000\000\022\000\021\000\022\000\022\000\022\000\000\000\000\000\
\000\000\000\000\000\000\022\000\022\000\022\000\000\000\023\000\
\000\000\023\000\023\000\000\000\022\000\023\000\000\000\000\000\
\000\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\000\000\023\000\000\000\000\000\023\000\023\000\023\000\023\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\000\000\023\000\020\000\
\023\000\023\000\023\000\000\000\000\000\000\000\000\000\000\000\
\023\000\023\000\023\000\000\000\024\000\000\000\024\000\024\000\
\000\000\023\000\024\000\000\000\000\000\000\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\000\000\024\000\000\000\
\000\000\024\000\024\000\024\000\024\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\000\000\024\000\008\000\024\000\024\000\024\000\
\000\000\000\000\000\000\000\000\000\000\024\000\024\000\024\000\
\000\000\043\000\000\000\043\000\043\000\000\000\024\000\043\000\
\000\000\000\000\000\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\000\000\043\000\000\000\000\000\043\000\043\000\
\043\000\043\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\000\000\
\043\000\005\000\043\000\043\000\043\000\000\000\000\000\000\000\
\000\000\000\000\043\000\043\000\043\000\000\000\000\000\000\000\
\000\000\000\000\042\000\043\000\042\000\042\000\000\000\000\000\
\042\000\000\000\000\000\000\000\042\000\042\000\042\000\042\000\
\042\000\042\000\042\000\000\000\042\000\000\000\000\000\042\000\
\042\000\042\000\042\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
\000\000\042\000\004\000\042\000\042\000\042\000\000\000\000\000\
\000\000\000\000\000\000\042\000\042\000\042\000\000\000\000\000\
\021\000\000\000\021\000\021\000\042\000\000\000\021\000\000\000\
\000\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\
\021\000\000\000\021\000\000\000\000\000\021\000\021\000\021\000\
\021\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\000\
\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\000\
\033\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\
\000\000\021\000\021\000\021\000\000\000\020\000\000\000\020\000\
\020\000\000\000\021\000\020\000\000\000\000\000\000\000\020\000\
\020\000\020\000\020\000\020\000\020\000\020\000\000\000\020\000\
\000\000\000\000\020\000\020\000\020\000\020\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\020\000\020\000\020\000\020\000\
\000\000\000\000\000\000\000\000\020\000\009\000\020\000\020\000\
\020\000\000\000\000\000\000\000\000\000\000\000\020\000\020\000\
\020\000\000\000\008\000\000\000\008\000\008\000\000\000\020\000\
\008\000\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\000\000\008\000\000\000\000\000\008\000\
\008\000\008\000\008\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\008\000\008\000\000\000\000\000\000\000\000\000\000\000\
\000\000\008\000\003\000\008\000\008\000\008\000\000\000\000\000\
\000\000\000\000\000\000\008\000\008\000\008\000\000\000\005\000\
\000\000\005\000\005\000\000\000\008\000\005\000\000\000\000\000\
\000\000\000\000\000\000\044\000\000\000\000\000\000\000\005\000\
\002\000\005\000\000\000\000\000\005\000\005\000\005\000\005\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
\005\000\005\000\005\000\000\000\000\000\000\000\000\000\000\000\
\005\000\005\000\005\000\000\000\000\000\000\000\000\000\000\000\
\004\000\005\000\004\000\004\000\000\000\000\000\004\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\001\000\000\000\
\004\000\000\000\004\000\010\000\000\000\004\000\004\000\004\000\
\004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\004\000\
\000\000\000\000\000\000\000\000\011\000\000\000\000\000\004\000\
\000\000\004\000\004\000\004\000\000\000\000\000\000\000\000\000\
\000\000\004\000\004\000\004\000\000\000\000\000\033\000\000\000\
\033\000\033\000\004\000\000\000\033\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\033\000\000\000\
\033\000\000\000\000\000\033\000\033\000\033\000\033\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\040\000\000\000\
\000\000\000\000\000\000\000\000\000\000\033\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\033\000\000\000\033\000\
\033\000\033\000\000\000\000\000\000\000\000\000\000\000\033\000\
\033\000\033\000\000\000\009\000\000\000\009\000\009\000\000\000\
\033\000\009\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\009\000\000\000\009\000\000\000\000\000\
\009\000\009\000\009\000\009\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\009\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\009\000\000\000\009\000\009\000\009\000\000\000\
\000\000\000\000\000\000\000\000\009\000\009\000\009\000\000\000\
\003\000\000\000\003\000\003\000\000\000\009\000\003\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\003\000\000\000\003\000\000\000\000\000\003\000\003\000\000\000\
\003\000\044\000\000\000\044\000\044\000\000\000\002\000\044\000\
\002\000\002\000\000\000\000\000\002\000\000\000\000\000\003\000\
\000\000\044\000\000\000\044\000\000\000\000\000\002\000\003\000\
\002\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
\000\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
\044\000\000\000\003\000\000\000\000\000\002\000\000\000\000\000\
\044\000\000\000\044\000\044\000\044\000\002\000\000\000\002\000\
\002\000\002\000\044\000\044\000\044\000\000\000\000\000\002\000\
\002\000\002\000\000\000\044\000\001\000\000\000\001\000\001\000\
\002\000\010\000\001\000\010\000\010\000\000\000\000\000\010\000\
\000\000\000\000\000\000\000\000\001\000\000\000\001\000\000\000\
\000\000\010\000\000\000\010\000\000\000\000\000\000\000\000\000\
\000\000\000\000\011\000\000\000\011\000\011\000\000\000\000\000\
\011\000\000\000\000\000\001\000\000\000\000\000\000\000\000\000\
\010\000\000\000\011\000\001\000\011\000\001\000\001\000\001\000\
\010\000\000\000\010\000\010\000\010\000\001\000\001\000\001\000\
\000\000\000\000\010\000\010\000\010\000\000\000\001\000\000\000\
\000\000\011\000\000\000\010\000\000\000\000\000\000\000\000\000\
\000\000\011\000\000\000\011\000\011\000\011\000\000\000\000\000\
\000\000\040\000\000\000\011\000\011\000\011\000\040\000\040\000\
\040\000\040\000\040\000\040\000\011\000\040\000\000\000\000\000\
\000\000\040\000\040\000\040\000\040\000\000\000\000\000\000\000\
\048\000\000\000\051\000\052\000\000\000\000\000\000\000\000\000\
\000\000\077\000\000\000\000\000\040\000\040\000\040\000\040\000\
\040\000\040\000\040\000\000\000\000\000\040\000\089\000\091\000\
\092\000\000\000\050\000\097\000\000\000\024\000\025\000\040\000\
\026\000\000\000\000\000\000\000\000\000\000\000\027\000\000\000\
\000\000\108\000\109\000\110\000\000\000\000\000\000\000\000\000\
\000\000\000\000\028\000\029\000\000\000\000\000\000\000\000\000\
\030\000\031\000\032\000\033\000\034\000\035\000\036\000\037\000\
\038\000\039\000\040\000\041\000\042\000\043\000\000\000\000\000\
\044\000\045\000\046\000\000\000\000\000\000\000\000\000\000\000\
\159\000\000\000\000\000\160\000\163\000\164\000\047\000\000\000\
\000\000\000\000\000\000\053\000\000\000\000\000\000\000\172\000\
\173\000\174\000\175\000\176\000\177\000\178\000\179\000\180\000\
\181\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\184\000\185\000\186\000\187\000\
\188\000\189\000\190\000\191\000\192\000\193\000\194\000\196\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\050\000\000\000\
\204\000\024\000\025\000\000\000\026\000\000\000\208\000\000\000\
\000\000\209\000\027\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\215\000\216\000\217\000\218\000\028\000\029\000\
\221\000\000\000\000\000\000\000\030\000\031\000\032\000\033\000\
\034\000\035\000\036\000\037\000\038\000\039\000\040\000\041\000\
\042\000\043\000\000\000\000\000\044\000\045\000\046\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\047\000\239\000\242\000\000\000\000\000\000\000\
\000\000\000\000\160\000\000\000\238\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\249\000\
\250\000\000\000\251\000\252\000\000\000\253\000\000\000\254\000\
\000\000\000\000\000\000\239\000\000\000\000\000\000\000\000\000\
\000\000\050\000\000\000\006\001\024\000\025\000\000\000\026\000\
\000\000\000\000\000\000\000\000\000\000\027\000\000\000\015\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\018\001\028\000\029\000\000\000\000\000\239\000\000\000\030\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\038\000\
\039\000\040\000\041\000\042\000\043\000\000\000\111\000\044\000\
\045\000\046\000\000\000\112\000\113\000\114\000\115\000\116\000\
\117\000\000\000\118\000\000\000\000\000\047\000\119\000\120\000\
\121\000\122\000\154\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\123\000\124\000\125\000\126\000\127\000\128\000\129\000\
\050\000\000\000\000\000\024\000\025\000\000\000\026\000\000\000\
\000\000\000\000\000\000\000\000\027\000\000\000\000\000\000\000\
\000\000\000\000\000\000\020\001\000\000\000\000\000\000\000\000\
\028\000\029\000\000\000\000\000\000\000\000\000\030\000\031\000\
\032\000\033\000\034\000\035\000\036\000\037\000\038\000\039\000\
\040\000\041\000\042\000\043\000\000\000\000\000\044\000\045\000\
\046\000\000\000\023\000\000\000\241\000\024\000\025\000\000\000\
\026\000\000\000\000\000\000\000\047\000\000\000\027\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\028\000\029\000\000\000\000\000\000\000\000\000\
\030\000\031\000\032\000\033\000\034\000\035\000\036\000\037\000\
\038\000\039\000\040\000\041\000\042\000\043\000\000\000\000\000\
\044\000\045\000\046\000\050\000\000\000\000\000\024\000\025\000\
\000\000\026\000\000\000\000\000\000\000\000\000\047\000\027\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\028\000\029\000\000\000\000\000\000\000\
\000\000\030\000\031\000\032\000\033\000\034\000\035\000\036\000\
\037\000\038\000\039\000\040\000\041\000\042\000\043\000\000\000\
\000\000\044\000\045\000\046\000\050\000\000\000\000\000\024\000\
\025\000\000\000\026\000\000\000\000\000\000\000\000\000\047\000\
\027\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\028\000\029\000\000\000\000\000\
\000\000\000\000\030\000\031\000\032\000\033\000\034\000\035\000\
\036\000\037\000\038\000\039\000\040\000\041\000\042\000\043\000\
\000\000\111\000\000\000\000\000\000\000\000\000\112\000\113\000\
\114\000\115\000\116\000\117\000\000\000\118\000\000\000\000\000\
\047\000\119\000\120\000\121\000\122\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\123\000\124\000\125\000\126\000\
\127\000\128\000\129\000\222\000\000\000\000\000\000\000\212\000\
\111\000\000\000\000\000\000\000\000\000\112\000\113\000\114\000\
\115\000\116\000\117\000\000\000\118\000\000\000\000\000\000\000\
\119\000\120\000\121\000\122\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\123\000\124\000\125\000\126\000\127\000\
\128\000\129\000\224\000\000\000\000\000\000\000\000\000\111\000\
\000\000\000\000\000\000\000\000\112\000\113\000\114\000\115\000\
\116\000\117\000\000\000\118\000\000\000\000\000\000\000\119\000\
\120\000\121\000\122\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\123\000\124\000\125\000\126\000\127\000\128\000\
\129\000\225\000\000\000\000\000\000\000\000\000\111\000\000\000\
\000\000\000\000\000\000\112\000\113\000\114\000\115\000\116\000\
\117\000\000\000\118\000\000\000\000\000\000\000\119\000\120\000\
\121\000\122\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\123\000\124\000\125\000\126\000\127\000\128\000\129\000\
\228\000\000\000\000\000\000\000\000\000\111\000\000\000\000\000\
\000\000\000\000\112\000\113\000\114\000\115\000\116\000\117\000\
\000\000\118\000\000\000\000\000\000\000\119\000\120\000\121\000\
\122\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\123\000\124\000\125\000\126\000\127\000\128\000\129\000\231\000\
\000\000\000\000\000\000\000\000\111\000\000\000\000\000\000\000\
\000\000\112\000\113\000\114\000\115\000\116\000\117\000\000\000\
\118\000\000\000\000\000\000\000\119\000\120\000\121\000\122\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000\008\001\000\000\
\000\000\000\000\000\000\111\000\000\000\000\000\000\000\000\000\
\112\000\113\000\114\000\115\000\116\000\117\000\000\000\118\000\
\000\000\000\000\000\000\119\000\120\000\121\000\122\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\123\000\124\000\
\125\000\126\000\127\000\128\000\129\000\009\001\000\000\000\000\
\000\000\000\000\111\000\000\000\000\000\000\000\000\000\112\000\
\113\000\114\000\115\000\116\000\117\000\000\000\118\000\000\000\
\000\000\000\000\119\000\120\000\121\000\122\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\123\000\124\000\125\000\
\126\000\127\000\128\000\129\000\010\001\000\000\000\000\000\000\
\000\000\111\000\000\000\000\000\000\000\000\000\112\000\113\000\
\114\000\115\000\116\000\117\000\000\000\118\000\000\000\000\000\
\000\000\119\000\120\000\121\000\122\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\123\000\124\000\125\000\126\000\
\127\000\128\000\129\000\023\001\000\000\000\000\000\000\000\000\
\111\000\000\000\000\000\000\000\000\000\112\000\113\000\114\000\
\115\000\116\000\117\000\000\000\118\000\000\000\000\000\000\000\
\119\000\120\000\121\000\122\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\123\000\124\000\125\000\126\000\127\000\
\128\000\129\000\246\000\000\000\000\000\111\000\000\000\000\000\
\000\000\000\000\112\000\113\000\114\000\115\000\116\000\117\000\
\000\000\118\000\232\000\000\000\111\000\119\000\120\000\121\000\
\122\000\112\000\113\000\114\000\115\000\116\000\117\000\000\000\
\118\000\000\000\000\000\000\000\119\000\120\000\121\000\122\000\
\123\000\124\000\125\000\126\000\127\000\128\000\129\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000\111\000\000\000\
\000\000\000\000\000\000\112\000\113\000\114\000\115\000\116\000\
\117\000\000\000\118\000\000\000\000\000\111\000\119\000\120\000\
\121\000\122\000\112\000\113\000\114\000\115\000\116\000\117\000\
\000\000\118\000\000\000\000\000\000\000\119\000\120\000\121\000\
\122\000\123\000\124\000\125\000\126\000\127\000\128\000\129\000\
\233\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\123\000\124\000\125\000\126\000\127\000\128\000\129\000\005\001\
\111\000\000\000\000\000\000\000\000\000\112\000\113\000\114\000\
\115\000\116\000\117\000\000\000\118\000\000\000\000\000\000\000\
\119\000\120\000\121\000\122\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\167\000\123\000\124\000\125\000\126\000\127\000\
\128\000\129\000\111\000\000\000\000\000\000\000\000\000\112\000\
\113\000\114\000\115\000\116\000\117\000\213\000\118\000\000\000\
\000\000\111\000\119\000\120\000\121\000\122\000\112\000\113\000\
\114\000\115\000\116\000\117\000\223\000\118\000\000\000\000\000\
\000\000\119\000\120\000\121\000\122\000\123\000\124\000\125\000\
\126\000\127\000\128\000\129\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\123\000\124\000\125\000\126\000\
\127\000\128\000\129\000\111\000\000\000\000\000\000\000\000\000\
\112\000\113\000\114\000\115\000\116\000\117\000\226\000\118\000\
\000\000\000\000\111\000\119\000\120\000\121\000\122\000\112\000\
\113\000\114\000\115\000\116\000\117\000\227\000\118\000\000\000\
\000\000\000\000\119\000\120\000\121\000\122\000\123\000\124\000\
\125\000\126\000\127\000\128\000\129\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\123\000\124\000\125\000\
\126\000\127\000\128\000\129\000\111\000\000\000\000\000\000\000\
\000\000\112\000\113\000\114\000\115\000\116\000\117\000\229\000\
\118\000\000\000\000\000\111\000\119\000\120\000\121\000\122\000\
\112\000\113\000\114\000\115\000\116\000\117\000\230\000\118\000\
\000\000\000\000\000\000\119\000\120\000\121\000\122\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\123\000\124\000\
\125\000\126\000\127\000\128\000\129\000\111\000\000\000\000\000\
\000\000\000\000\112\000\113\000\114\000\115\000\116\000\117\000\
\011\001\118\000\000\000\000\000\111\000\119\000\120\000\121\000\
\122\000\112\000\113\000\114\000\115\000\116\000\117\000\000\000\
\118\000\000\000\000\000\000\000\119\000\120\000\121\000\122\000\
\123\000\124\000\125\000\126\000\127\000\128\000\129\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000\111\000\000\000\
\000\000\000\000\000\000\112\000\113\000\114\000\115\000\116\000\
\117\000\000\000\118\000\000\000\111\000\000\000\000\000\000\000\
\121\000\112\000\113\000\114\000\115\000\116\000\117\000\000\000\
\118\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\123\000\124\000\125\000\126\000\127\000\128\000\129\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000"

let yycheck = "\079\000\
\000\000\006\001\000\000\000\000\000\000\000\000\081\000\000\000\
\014\001\000\000\000\000\000\000\028\000\029\000\014\001\015\001\
\001\001\022\001\006\001\022\001\006\001\006\001\005\001\001\001\
\011\001\238\000\009\001\010\001\006\001\001\001\005\001\001\001\
\000\000\003\001\006\001\010\001\023\001\000\000\080\001\081\001\
\001\000\001\001\000\000\000\000\014\001\015\001\001\001\001\001\
\067\001\064\001\014\001\131\000\071\001\065\001\001\001\060\001\
\003\001\004\001\005\001\016\001\007\001\055\001\000\000\049\001\
\049\001\052\001\013\001\014\001\015\001\072\001\076\001\049\001\
\060\001\079\001\080\001\000\000\076\001\049\001\025\001\026\001\
\005\001\081\001\005\001\005\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\005\001\000\000\047\001\048\001\049\001\005\001\
\005\001\075\001\076\001\077\001\078\001\079\001\080\001\081\001\
\076\001\005\001\061\001\079\001\080\001\005\001\005\001\005\001\
\049\001\049\001\022\001\000\000\001\001\005\001\009\001\001\001\
\075\001\076\001\077\001\078\001\079\001\080\001\081\001\210\000\
\063\001\001\001\022\001\024\001\011\001\060\001\060\001\001\001\
\001\001\049\001\080\001\080\001\024\001\005\001\022\001\056\001\
\023\001\006\001\170\000\054\001\052\001\052\001\012\001\058\001\
\059\001\001\001\006\001\062\001\004\001\005\001\065\001\007\001\
\001\001\068\001\069\001\070\001\053\001\013\001\073\001\074\001\
\001\001\001\001\049\001\050\001\051\001\052\001\000\000\006\001\
\000\000\025\001\026\001\053\001\006\001\013\001\001\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\067\001\000\000\047\001\
\048\001\049\001\024\001\006\001\006\001\012\001\001\001\006\001\
\000\000\011\001\000\000\000\000\006\001\061\001\016\001\017\001\
\018\001\019\001\020\001\021\001\000\000\023\001\012\001\071\001\
\072\001\027\001\028\001\029\001\030\001\000\000\000\000\000\000\
\053\001\053\001\000\000\008\000\213\000\000\000\234\000\025\000\
\017\000\017\000\201\000\205\000\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\011\001\255\255\255\255\006\001\255\255\
\008\001\009\001\255\255\011\001\012\001\255\255\255\255\023\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\022\001\255\255\027\001\028\001\029\001\030\001\022\001\
\022\001\024\001\255\255\255\255\255\255\255\255\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\000\000\055\001\
\056\001\057\001\056\001\055\001\255\255\056\001\055\001\063\001\
\064\001\065\001\055\001\255\255\006\001\065\001\008\001\009\001\
\072\001\011\001\012\001\072\001\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\055\001\
\056\001\027\001\028\001\029\001\030\001\056\001\255\255\063\001\
\064\001\055\001\056\001\056\001\063\001\064\001\255\255\255\255\
\255\255\063\001\063\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\000\000\055\001\056\001\057\001\
\255\255\022\001\255\255\255\255\255\255\063\001\064\001\065\001\
\255\255\006\001\255\255\008\001\009\001\255\255\072\001\012\001\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\255\255\024\001\255\255\255\255\027\001\028\001\
\029\001\030\001\055\001\056\001\255\255\255\255\255\255\255\255\
\255\255\255\255\063\001\255\255\255\255\255\255\255\255\255\255\
\045\001\046\001\047\001\048\001\049\001\050\001\051\001\255\255\
\053\001\000\000\055\001\056\001\057\001\255\255\255\255\255\255\
\255\255\255\255\063\001\064\001\065\001\255\255\006\001\255\255\
\008\001\009\001\255\255\072\001\012\001\255\255\255\255\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\255\255\
\024\001\255\255\255\255\027\001\028\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\255\255\053\001\000\000\055\001\
\056\001\057\001\255\255\255\255\255\255\255\255\255\255\063\001\
\064\001\065\001\255\255\006\001\255\255\008\001\009\001\255\255\
\072\001\012\001\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\255\255\024\001\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\255\255\053\001\000\000\055\001\056\001\057\001\255\255\
\255\255\255\255\255\255\255\255\063\001\064\001\065\001\255\255\
\255\255\255\255\255\255\255\255\006\001\072\001\008\001\009\001\
\255\255\255\255\012\001\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\255\255\024\001\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\255\255\053\001\000\000\055\001\056\001\057\001\
\255\255\255\255\255\255\255\255\255\255\063\001\064\001\065\001\
\255\255\255\255\006\001\255\255\008\001\009\001\072\001\255\255\
\012\001\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\255\255\024\001\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\045\001\046\001\047\001\048\001\049\001\050\001\051\001\
\255\255\053\001\000\000\055\001\056\001\057\001\255\255\255\255\
\255\255\255\255\255\255\063\001\064\001\065\001\255\255\006\001\
\255\255\008\001\009\001\255\255\072\001\012\001\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\255\255\024\001\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\045\001\046\001\
\047\001\048\001\049\001\050\001\051\001\255\255\053\001\000\000\
\055\001\056\001\057\001\255\255\255\255\255\255\255\255\255\255\
\063\001\064\001\065\001\255\255\006\001\255\255\008\001\009\001\
\255\255\072\001\012\001\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\255\255\024\001\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\255\255\053\001\000\000\055\001\056\001\057\001\
\255\255\255\255\255\255\255\255\255\255\063\001\064\001\065\001\
\255\255\006\001\255\255\008\001\009\001\255\255\072\001\012\001\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\255\255\024\001\255\255\255\255\027\001\028\001\
\029\001\030\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\045\001\046\001\047\001\048\001\049\001\050\001\051\001\255\255\
\053\001\000\000\055\001\056\001\057\001\255\255\255\255\255\255\
\255\255\255\255\063\001\064\001\065\001\255\255\255\255\255\255\
\255\255\255\255\006\001\072\001\008\001\009\001\255\255\255\255\
\012\001\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\255\255\024\001\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\045\001\046\001\047\001\048\001\049\001\050\001\051\001\
\255\255\053\001\000\000\055\001\056\001\057\001\255\255\255\255\
\255\255\255\255\255\255\063\001\064\001\065\001\255\255\255\255\
\006\001\255\255\008\001\009\001\072\001\255\255\012\001\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\255\255\024\001\255\255\255\255\027\001\028\001\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\045\001\
\046\001\047\001\048\001\255\255\255\255\255\255\255\255\053\001\
\000\000\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\063\001\064\001\065\001\255\255\006\001\255\255\008\001\
\009\001\255\255\072\001\012\001\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\255\255\024\001\
\255\255\255\255\027\001\028\001\029\001\030\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\045\001\046\001\047\001\048\001\
\255\255\255\255\255\255\255\255\053\001\000\000\055\001\056\001\
\057\001\255\255\255\255\255\255\255\255\255\255\063\001\064\001\
\065\001\255\255\006\001\255\255\008\001\009\001\255\255\072\001\
\012\001\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\255\255\024\001\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\045\001\046\001\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\000\000\055\001\056\001\057\001\255\255\255\255\
\255\255\255\255\255\255\063\001\064\001\065\001\255\255\006\001\
\255\255\008\001\009\001\255\255\072\001\012\001\255\255\255\255\
\255\255\255\255\255\255\000\000\255\255\255\255\255\255\022\001\
\000\000\024\001\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\045\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\053\001\255\255\
\055\001\056\001\057\001\255\255\255\255\255\255\255\255\255\255\
\063\001\064\001\065\001\255\255\255\255\255\255\255\255\255\255\
\006\001\072\001\008\001\009\001\255\255\255\255\012\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
\022\001\255\255\024\001\000\000\255\255\027\001\028\001\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\045\001\
\255\255\255\255\255\255\255\255\000\000\255\255\255\255\053\001\
\255\255\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\063\001\064\001\065\001\255\255\255\255\006\001\255\255\
\008\001\009\001\072\001\255\255\012\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\022\001\255\255\
\024\001\255\255\255\255\027\001\028\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
\255\255\255\255\255\255\255\255\255\255\045\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\053\001\255\255\055\001\
\056\001\057\001\255\255\255\255\255\255\255\255\255\255\063\001\
\064\001\065\001\255\255\006\001\255\255\008\001\009\001\255\255\
\072\001\012\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\022\001\255\255\024\001\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\045\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\255\255\055\001\056\001\057\001\255\255\
\255\255\255\255\255\255\255\255\063\001\064\001\065\001\255\255\
\006\001\255\255\008\001\009\001\255\255\072\001\012\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\022\001\255\255\024\001\255\255\255\255\027\001\028\001\255\255\
\030\001\006\001\255\255\008\001\009\001\255\255\006\001\012\001\
\008\001\009\001\255\255\255\255\012\001\255\255\255\255\045\001\
\255\255\022\001\255\255\024\001\255\255\255\255\022\001\053\001\
\024\001\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\063\001\064\001\065\001\255\255\255\255\255\255\255\255\
\045\001\255\255\072\001\255\255\255\255\045\001\255\255\255\255\
\053\001\255\255\055\001\056\001\057\001\053\001\255\255\055\001\
\056\001\057\001\063\001\064\001\065\001\255\255\255\255\063\001\
\064\001\065\001\255\255\072\001\006\001\255\255\008\001\009\001\
\072\001\006\001\012\001\008\001\009\001\255\255\255\255\012\001\
\255\255\255\255\255\255\255\255\022\001\255\255\024\001\255\255\
\255\255\022\001\255\255\024\001\255\255\255\255\255\255\255\255\
\255\255\255\255\006\001\255\255\008\001\009\001\255\255\255\255\
\012\001\255\255\255\255\045\001\255\255\255\255\255\255\255\255\
\045\001\255\255\022\001\053\001\024\001\055\001\056\001\057\001\
\053\001\255\255\055\001\056\001\057\001\063\001\064\001\065\001\
\255\255\255\255\063\001\064\001\065\001\255\255\072\001\255\255\
\255\255\045\001\255\255\072\001\255\255\255\255\255\255\255\255\
\255\255\053\001\255\255\055\001\056\001\057\001\255\255\255\255\
\255\255\011\001\255\255\063\001\064\001\065\001\016\001\017\001\
\018\001\019\001\020\001\021\001\072\001\023\001\255\255\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\003\000\255\255\005\000\006\000\255\255\255\255\255\255\255\255\
\255\255\012\000\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\255\255\055\001\025\000\026\000\
\027\000\255\255\001\001\030\000\255\255\004\001\005\001\065\001\
\007\001\255\255\255\255\255\255\255\255\255\255\013\001\255\255\
\255\255\044\000\045\000\046\000\255\255\255\255\255\255\255\255\
\255\255\255\255\025\001\026\001\255\255\255\255\255\255\255\255\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\255\255\255\255\
\047\001\048\001\049\001\255\255\255\255\255\255\255\255\255\255\
\083\000\255\255\255\255\086\000\087\000\088\000\061\001\255\255\
\255\255\255\255\255\255\066\001\255\255\255\255\255\255\098\000\
\099\000\100\000\101\000\102\000\103\000\104\000\105\000\106\000\
\107\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\119\000\120\000\121\000\122\000\
\123\000\124\000\125\000\126\000\127\000\128\000\129\000\130\000\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\001\001\255\255\
\147\000\004\001\005\001\255\255\007\001\255\255\153\000\255\255\
\255\255\156\000\013\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\165\000\166\000\167\000\168\000\025\001\026\001\
\171\000\255\255\255\255\255\255\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\255\255\255\255\047\001\048\001\049\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\206\000\207\000\255\255\255\255\255\255\
\255\255\255\255\213\000\255\255\071\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\226\000\
\227\000\255\255\229\000\230\000\255\255\232\000\255\255\234\000\
\255\255\255\255\255\255\238\000\255\255\255\255\255\255\255\255\
\255\255\001\001\255\255\246\000\004\001\005\001\255\255\007\001\
\255\255\255\255\255\255\255\255\255\255\013\001\255\255\002\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\011\001\025\001\026\001\255\255\255\255\016\001\255\255\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\255\255\011\001\047\001\
\048\001\049\001\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\255\255\023\001\255\255\255\255\061\001\027\001\028\001\
\029\001\030\001\066\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\001\001\255\255\255\255\004\001\005\001\255\255\007\001\255\255\
\255\255\255\255\255\255\255\255\013\001\255\255\255\255\255\255\
\255\255\255\255\255\255\072\001\255\255\255\255\255\255\255\255\
\025\001\026\001\255\255\255\255\255\255\255\255\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\255\255\255\255\047\001\048\001\
\049\001\255\255\001\001\255\255\053\001\004\001\005\001\255\255\
\007\001\255\255\255\255\255\255\061\001\255\255\013\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\025\001\026\001\255\255\255\255\255\255\255\255\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\255\255\255\255\
\047\001\048\001\049\001\001\001\255\255\255\255\004\001\005\001\
\255\255\007\001\255\255\255\255\255\255\255\255\061\001\013\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\025\001\026\001\255\255\255\255\255\255\
\255\255\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\255\255\
\255\255\047\001\048\001\049\001\001\001\255\255\255\255\004\001\
\005\001\255\255\007\001\255\255\255\255\255\255\255\255\061\001\
\013\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\025\001\026\001\255\255\255\255\
\255\255\255\255\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\041\001\042\001\043\001\044\001\
\255\255\011\001\255\255\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\255\255\023\001\255\255\255\255\
\061\001\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\006\001\255\255\255\255\255\255\057\001\
\011\001\255\255\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\255\255\023\001\255\255\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\046\001\047\001\048\001\049\001\050\001\051\001\
\052\001\006\001\255\255\255\255\255\255\255\255\011\001\255\255\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\255\255\023\001\255\255\255\255\255\255\027\001\028\001\
\029\001\030\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\006\001\255\255\255\255\255\255\255\255\011\001\255\255\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\255\255\023\001\255\255\255\255\255\255\027\001\028\001\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\006\001\
\255\255\255\255\255\255\255\255\011\001\255\255\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\255\255\
\023\001\255\255\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\006\001\255\255\
\255\255\255\255\255\255\011\001\255\255\255\255\255\255\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\255\255\023\001\
\255\255\255\255\255\255\027\001\028\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\006\001\255\255\255\255\
\255\255\255\255\011\001\255\255\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\255\255\023\001\255\255\
\255\255\255\255\027\001\028\001\029\001\030\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\006\001\255\255\255\255\255\255\
\255\255\011\001\255\255\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\255\255\023\001\255\255\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\006\001\255\255\255\255\255\255\255\255\
\011\001\255\255\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\255\255\023\001\255\255\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\008\001\255\255\255\255\011\001\255\255\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\255\255\023\001\009\001\255\255\011\001\027\001\028\001\029\001\
\030\001\016\001\017\001\018\001\019\001\020\001\021\001\255\255\
\023\001\255\255\255\255\255\255\027\001\028\001\029\001\030\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\011\001\255\255\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\255\255\023\001\255\255\255\255\011\001\027\001\028\001\
\029\001\030\001\016\001\017\001\018\001\019\001\020\001\021\001\
\255\255\023\001\255\255\255\255\255\255\027\001\028\001\029\001\
\030\001\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\011\001\255\255\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\255\255\023\001\255\255\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\011\001\255\255\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\255\255\
\255\255\011\001\027\001\028\001\029\001\030\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\255\255\255\255\
\255\255\027\001\028\001\029\001\030\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\011\001\255\255\255\255\255\255\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\255\255\255\255\011\001\027\001\028\001\029\001\030\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\255\255\
\255\255\255\255\027\001\028\001\029\001\030\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\011\001\255\255\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\255\255\255\255\011\001\027\001\028\001\029\001\030\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\255\255\255\255\255\255\027\001\028\001\029\001\030\001\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\011\001\255\255\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\255\255\255\255\011\001\027\001\028\001\029\001\
\030\001\016\001\017\001\018\001\019\001\020\001\021\001\255\255\
\023\001\255\255\255\255\255\255\027\001\028\001\029\001\030\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\011\001\255\255\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\255\255\023\001\255\255\011\001\255\255\255\255\255\255\
\029\001\016\001\017\001\018\001\019\001\020\001\021\001\255\255\
\023\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001"

let yynames_const = "\
  LPAR\000\
  RPAR\000\
  IF\000\
  ELSE\000\
  COLON\000\
  COLONCOLON\000\
  DOT\000\
  DOTDOT\000\
  AMP\000\
  INT\000\
  FLOAT\000\
  LT\000\
  GT\000\
  LE\000\
  GE\000\
  EQ\000\
  NE\000\
  COMMA\000\
  ARROW\000\
  EQUAL\000\
  FORALL\000\
  EXISTS\000\
  IFF\000\
  IMPLIES\000\
  AND\000\
  OR\000\
  NOT\000\
  TRUE\000\
  FALSE\000\
  OLD\000\
  AT\000\
  RESULT\000\
  BLOCK_LENGTH\000\
  BASE_ADDR\000\
  SEPARATED\000\
  FULLSEPARATED\000\
  VALID\000\
  VALID_INDEX\000\
  VALID_RANGE\000\
  FRESH\000\
  THEN\000\
  QUESTION\000\
  MINUS\000\
  PLUS\000\
  STAR\000\
  SLASH\000\
  PERCENT\000\
  LSQUARE\000\
  RSQUARE\000\
  EOF\000\
  INVARIANT\000\
  VARIANT\000\
  DECREASES\000\
  FOR\000\
  LABEL\000\
  ASSERT\000\
  SEMICOLON\000\
  NULL\000\
  REQUIRES\000\
  ENSURES\000\
  ASSIGNS\000\
  LOOP_ASSIGNS\000\
  NOTHING\000\
  READS\000\
  LOGIC\000\
  PREDICATE\000\
  AXIOM\000\
  LBRACE\000\
  RBRACE\000\
  GHOST\000\
  SET\000\
  VOID\000\
  CHAR\000\
  SIGNED\000\
  UNSIGNED\000\
  SHORT\000\
  LONG\000\
  DOUBLE\000\
  STRUCT\000\
  ENUM\000\
  UNION\000\
  "

let yynames_block = "\
  IDENTIFIER\000\
  STRING_LITERAL\000\
  TYPENAME\000\
  CONSTANT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 90 "c/clparser.mly"
                      ( info (PLimplies (_1, _3)) )
# 1238 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 91 "c/clparser.mly"
                  ( info (PLiff (_1, _3)) )
# 1246 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 92 "c/clparser.mly"
                     ( info (PLor (_1, _3)) )
# 1254 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 93 "c/clparser.mly"
                     ( info (PLand (_1, _3)) )
# 1262 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 94 "c/clparser.mly"
                           ( info (PLnot _2) )
# 1269 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    Obj.repr(
# 95 "c/clparser.mly"
       ( info PLtrue )
# 1275 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    Obj.repr(
# 96 "c/clparser.mly"
        ( info PLfalse )
# 1281 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _2 = (peek_val parser_env 1 : 'relation) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 97 "c/clparser.mly"
                                           ( info (PLrel (_1, _2, _3)) )
# 1290 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'lexpr) in
    let _4 = (peek_val parser_env 2 : 'lexpr) in
    let _6 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 99 "c/clparser.mly"
      ( info (PLif (_2, _4, _6)) )
# 1299 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'ne_parameters) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 101 "c/clparser.mly"
      ( info (PLforall (_2, _4)) )
# 1307 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'ne_parameters) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 103 "c/clparser.mly"
      ( info (PLexists (_2, _4)) )
# 1315 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 3 : 'lexpr) in
    let _5 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 104 "c/clparser.mly"
                                        ( info (PLseparated (_3,_5)) )
# 1323 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 3 : 'lexpr) in
    let _5 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 105 "c/clparser.mly"
                                            ( info (PLfullseparated (_3,_5)) )
# 1331 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 106 "c/clparser.mly"
                        ( info (PLvalid (_3)) )
# 1338 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 3 : 'lexpr) in
    let _5 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 107 "c/clparser.mly"
                                          ( info (PLvalid_index (_3,_5)) )
# 1346 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 5 : 'lexpr) in
    let _5 = (peek_val parser_env 3 : 'lexpr) in
    let _7 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 109 "c/clparser.mly"
      ( info (PLvalid_range (_3,_5,_7)) )
# 1355 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 110 "c/clparser.mly"
                        ( info (PLfresh (_3)) )
# 1362 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    Obj.repr(
# 112 "c/clparser.mly"
       ( info PLnull )
# 1368 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Clogic.constant) in
    Obj.repr(
# 113 "c/clparser.mly"
           ( info (PLconstant _1) )
# 1375 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 114 "c/clparser.mly"
                   ( info (PLbinop (_1, Badd, _3)) )
# 1383 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 115 "c/clparser.mly"
                    ( info (PLbinop (_1, Bsub, _3)) )
# 1391 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 116 "c/clparser.mly"
                   ( info (PLbinop (_1, Bmul, _3)) )
# 1399 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 117 "c/clparser.mly"
                    ( info (PLbinop (_1, Bdiv, _3)) )
# 1407 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 118 "c/clparser.mly"
                      ( info (PLbinop (_1, Bmod, _3)) )
# 1415 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 119 "c/clparser.mly"
                         ( info (PLarrow (_1, _3)) )
# 1423 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 120 "c/clparser.mly"
                       ( info (PLdot (_1, _3)) )
# 1431 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'lexpr) in
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 121 "c/clparser.mly"
                              ( info (PLarrget (_1, _3)) )
# 1439 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : 'lexpr) in
    let _3 = (peek_val parser_env 3 : 'lexpr_option) in
    let _5 = (peek_val parser_env 1 : 'lexpr_option) in
    Obj.repr(
# 123 "c/clparser.mly"
   ( info (PLrange (_1, _3, _5)) )
# 1448 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 124 "c/clparser.mly"
                                ( info (PLunop (Uminus, _2)) )
# 1455 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 125 "c/clparser.mly"
                               ( _2 )
# 1462 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 126 "c/clparser.mly"
             ( info (PLunop (Ustar, _2)) )
# 1469 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 127 "c/clparser.mly"
            ( info (PLunop (Uamp, _2)) )
# 1476 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'lexpr) in
    let _3 = (peek_val parser_env 2 : 'lexpr) in
    let _5 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 129 "c/clparser.mly"
    ( info (PLif (_1, _3, _5)) )
# 1485 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 130 "c/clparser.mly"
                      ( info (PLold _3) )
# 1492 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 3 : 'lexpr) in
    let _5 = (peek_val parser_env 1 : string) in
    Obj.repr(
# 131 "c/clparser.mly"
                                      ( info (PLat (_3, _5)) )
# 1500 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 132 "c/clparser.mly"
                            ( info (PLbase_addr _3) )
# 1507 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 133 "c/clparser.mly"
                               ( info (PLblock_length _3) )
# 1514 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    Obj.repr(
# 134 "c/clparser.mly"
         ( info PLresult )
# 1520 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 136 "c/clparser.mly"
                                 ( _2 )
# 1527 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 137 "c/clparser.mly"
             ( info (PLvar (Info.default_var_info _1)) )
# 1534 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 1 : 'lexpr_list) in
    Obj.repr(
# 139 "c/clparser.mly"
    ( info (PLapp (Info.default_logic_info _1, _3)) )
# 1542 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'logic_type_not_id) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 141 "c/clparser.mly"
                                                    ( info (PLcast (_2, _4)) )
# 1550 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'lexpr) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 143 "c/clparser.mly"
    ( match _2.lexpr_node with
	| PLvar x -> info (PLcast (LTvar x.Info.var_name, _4))
	| _ -> raise Parse_error )
# 1560 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 146 "c/clparser.mly"
                                               ( info (PLnamed (_1, _3)) )
# 1568 "c/clparser.ml"
               : 'lexpr))
; (fun parser_env ->
    Obj.repr(
# 150 "c/clparser.mly"
                ( None )
# 1574 "c/clparser.ml"
               : 'lexpr_option))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 151 "c/clparser.mly"
                ( Some _1 )
# 1581 "c/clparser.ml"
               : 'lexpr_option))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 155 "c/clparser.mly"
             ( LTvar _1 )
# 1588 "c/clparser.ml"
               : 'logic_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : 'stars) in
    Obj.repr(
# 156 "c/clparser.mly"
                   ( _2 (LTvar _1) )
# 1596 "c/clparser.ml"
               : 'logic_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logic_type_not_id) in
    Obj.repr(
# 157 "c/clparser.mly"
                    ( _1 )
# 1603 "c/clparser.ml"
               : 'logic_type))
; (fun parser_env ->
    Obj.repr(
# 161 "c/clparser.mly"
                 ( LTvoid )
# 1609 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 162 "c/clparser.mly"
                 ( LTint )
# 1615 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 163 "c/clparser.mly"
                 ( LTint )
# 1621 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 164 "c/clparser.mly"
                 ( LTint )
# 1627 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 165 "c/clparser.mly"
                 ( LTint )
# 1633 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 166 "c/clparser.mly"
                 ( LTint )
# 1639 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 167 "c/clparser.mly"
                 ( LTint )
# 1645 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 168 "c/clparser.mly"
                 ( LTint )
# 1651 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 169 "c/clparser.mly"
                 ( LTint )
# 1657 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 170 "c/clparser.mly"
                 ( LTint )
# 1663 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 171 "c/clparser.mly"
                 ( LTint )
# 1669 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 172 "c/clparser.mly"
                 ( LTint )
# 1675 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 173 "c/clparser.mly"
                 ( LTint )
# 1681 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 174 "c/clparser.mly"
                   ( LTint )
# 1687 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 176 "c/clparser.mly"
              ( LTint )
# 1693 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 178 "c/clparser.mly"
                     ( LTint )
# 1699 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 180 "c/clparser.mly"
              ( LTfloat )
# 1705 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 181 "c/clparser.mly"
              ( LTfloat )
# 1711 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 182 "c/clparser.mly"
              ( LTfloat )
# 1717 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 188 "c/clparser.mly"
                   ( LTvar _1 )
# 1724 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'logic_type_not_id) in
    Obj.repr(
# 189 "c/clparser.mly"
                         ( LTpointer _1 )
# 1731 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun parser_env ->
    Obj.repr(
# 193 "c/clparser.mly"
       ( fun t -> LTpointer t )
# 1737 "c/clparser.ml"
               : 'stars))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'stars) in
    Obj.repr(
# 194 "c/clparser.mly"
             ( fun t -> _1 (LTpointer t) )
# 1744 "c/clparser.ml"
               : 'stars))
; (fun parser_env ->
    Obj.repr(
# 198 "c/clparser.mly"
          ( Lt )
# 1750 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 199 "c/clparser.mly"
          ( Gt )
# 1756 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 200 "c/clparser.mly"
          ( Le )
# 1762 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 201 "c/clparser.mly"
          ( Ge )
# 1768 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 202 "c/clparser.mly"
          ( Eq )
# 1774 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 203 "c/clparser.mly"
          ( Neq )
# 1780 "c/clparser.ml"
               : 'relation))
; (fun parser_env ->
    Obj.repr(
# 207 "c/clparser.mly"
                ( [] )
# 1786 "c/clparser.ml"
               : 'lexpr_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ne_lexpr_list) in
    Obj.repr(
# 208 "c/clparser.mly"
                 ( _1 )
# 1793 "c/clparser.ml"
               : 'lexpr_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 212 "c/clparser.mly"
                           ( [_1] )
# 1800 "c/clparser.ml"
               : 'ne_lexpr_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'lexpr) in
    let _3 = (peek_val parser_env 0 : 'ne_lexpr_list) in
    Obj.repr(
# 213 "c/clparser.mly"
                            ( _1 :: _3 )
# 1808 "c/clparser.ml"
               : 'ne_lexpr_list))
; (fun parser_env ->
    Obj.repr(
# 217 "c/clparser.mly"
                ( None )
# 1814 "c/clparser.ml"
               : 'pre_condition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 218 "c/clparser.mly"
                 ( Some _2 )
# 1821 "c/clparser.ml"
               : 'pre_condition))
; (fun parser_env ->
    Obj.repr(
# 222 "c/clparser.mly"
                 ( None )
# 1827 "c/clparser.ml"
               : 'post_condition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 223 "c/clparser.mly"
                ( Some _2 )
# 1834 "c/clparser.ml"
               : 'post_condition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'pre_condition) in
    let _2 = (peek_val parser_env 2 : 'effects) in
    let _3 = (peek_val parser_env 1 : 'post_condition) in
    let _4 = (peek_val parser_env 0 : 'decreases) in
    Obj.repr(
# 228 "c/clparser.mly"
    ( { requires = _1; assigns = _2; ensures = _3; decreases = _4 } )
# 1844 "c/clparser.ml"
               : 'spec))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'invariant) in
    let _2 = (peek_val parser_env 1 : 'loop_effects) in
    let _3 = (peek_val parser_env 0 : 'variant) in
    Obj.repr(
# 233 "c/clparser.mly"
    ( { invariant = Some _1; loop_assigns = _2; variant = Some _3 } )
# 1853 "c/clparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'loop_effects) in
    let _2 = (peek_val parser_env 0 : 'variant) in
    Obj.repr(
# 235 "c/clparser.mly"
    ( { invariant = None; loop_assigns = _1; variant = Some _2 } )
# 1861 "c/clparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'invariant) in
    let _2 = (peek_val parser_env 0 : 'loop_effects) in
    Obj.repr(
# 237 "c/clparser.mly"
    ( { invariant = Some _1; loop_assigns = _2; variant = None } )
# 1869 "c/clparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ne_loop_effects) in
    Obj.repr(
# 239 "c/clparser.mly"
    ( { invariant = None; loop_assigns = Some _1; variant = None } )
# 1876 "c/clparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 243 "c/clparser.mly"
                  ( _2 )
# 1883 "c/clparser.ml"
               : 'invariant))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'lexpr) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 247 "c/clparser.mly"
                               ( (_2, Some _4) )
# 1891 "c/clparser.ml"
               : 'variant))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 248 "c/clparser.mly"
                               ( (_2, None) )
# 1898 "c/clparser.ml"
               : 'variant))
; (fun parser_env ->
    Obj.repr(
# 252 "c/clparser.mly"
                  ( None )
# 1904 "c/clparser.ml"
               : 'decreases))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'variant) in
    Obj.repr(
# 253 "c/clparser.mly"
                    ( Some _2 )
# 1911 "c/clparser.ml"
               : 'decreases))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'annotation) in
    Obj.repr(
# 257 "c/clparser.mly"
                   ( _1 )
# 1918 "c/clparser.ml"
               : Cast.parsed_annot))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'decl) in
    Obj.repr(
# 261 "c/clparser.mly"
                   ( Adecl [_1] )
# 1925 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ghost_decl) in
    Obj.repr(
# 262 "c/clparser.mly"
                   ( Adecl _1 )
# 1932 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'spec) in
    Obj.repr(
# 263 "c/clparser.mly"
                   ( Aspec _1 )
# 1939 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'loop_annot) in
    Obj.repr(
# 264 "c/clparser.mly"
                   ( Aloop_annot _1 )
# 1946 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 265 "c/clparser.mly"
                   ( Acode_annot (Assert _2) )
# 1953 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 266 "c/clparser.mly"
                   ( Acode_annot (Label _2) )
# 1960 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'ghost_lvalue) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 268 "c/clparser.mly"
                   ( Acode_annot(GhostSet(_2,_4)) )
# 1968 "c/clparser.ml"
               : 'annotation))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 271 "c/clparser.mly"
                    ( _1 )
# 1975 "c/clparser.ml"
               : 'ghost_lvalue))
; (fun parser_env ->
    Obj.repr(
# 275 "c/clparser.mly"
                ( None )
# 1981 "c/clparser.ml"
               : 'effects))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'locations) in
    Obj.repr(
# 276 "c/clparser.mly"
                    ( Some _2 )
# 1988 "c/clparser.ml"
               : 'effects))
; (fun parser_env ->
    Obj.repr(
# 277 "c/clparser.mly"
                  ( Some [] )
# 1994 "c/clparser.ml"
               : 'effects))
; (fun parser_env ->
    Obj.repr(
# 281 "c/clparser.mly"
                ( None )
# 2000 "c/clparser.ml"
               : 'loop_effects))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ne_loop_effects) in
    Obj.repr(
# 282 "c/clparser.mly"
                  ( Some _1 )
# 2007 "c/clparser.ml"
               : 'loop_effects))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'locations) in
    Obj.repr(
# 286 "c/clparser.mly"
                         ( _2 )
# 2014 "c/clparser.ml"
               : 'ne_loop_effects))
; (fun parser_env ->
    Obj.repr(
# 287 "c/clparser.mly"
                       ( [] )
# 2020 "c/clparser.ml"
               : 'ne_loop_effects))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'location) in
    Obj.repr(
# 291 "c/clparser.mly"
           ( [_1] )
# 2027 "c/clparser.ml"
               : 'locations))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'location) in
    let _3 = (peek_val parser_env 0 : 'locations) in
    Obj.repr(
# 292 "c/clparser.mly"
                           ( _1 :: _3 )
# 2035 "c/clparser.ml"
               : 'locations))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 296 "c/clparser.mly"
        ( _1 )
# 2042 "c/clparser.ml"
               : 'location))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'logic_type) in
    let _3 = (peek_val parser_env 3 : string) in
    let _5 = (peek_val parser_env 1 : 'parameters) in
    Obj.repr(
# 301 "c/clparser.mly"
    ( LDlogic (Info.default_logic_info _3, _2, _5, []) )
# 2051 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 6 : 'logic_type) in
    let _3 = (peek_val parser_env 5 : string) in
    let _5 = (peek_val parser_env 3 : 'parameters) in
    let _8 = (peek_val parser_env 0 : 'locations) in
    Obj.repr(
# 303 "c/clparser.mly"
    ( LDlogic (Info.default_logic_info _3, _2, _5, _8) )
# 2061 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _4 = (peek_val parser_env 1 : 'parameters) in
    Obj.repr(
# 305 "c/clparser.mly"
    ( LDpredicate_reads (Info.default_logic_info _2, _4, []) )
# 2069 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 5 : string) in
    let _4 = (peek_val parser_env 3 : 'parameters) in
    let _7 = (peek_val parser_env 0 : 'locations) in
    Obj.repr(
# 307 "c/clparser.mly"
    ( LDpredicate_reads (Info.default_logic_info _2, _4, _7) )
# 2078 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 6 : string) in
    let _4 = (peek_val parser_env 4 : 'parameters) in
    let _7 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 309 "c/clparser.mly"
    ( LDpredicate_def (Info.default_logic_info _2, _4, _7) )
# 2087 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 310 "c/clparser.mly"
                               ( LDaxiom (_2, _4) )
# 2095 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 311 "c/clparser.mly"
                                   ( LDinvariant (_2, _4) )
# 2103 "c/clparser.ml"
               : 'decl))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'type_specifier) in
    let _3 = (peek_val parser_env 0 : 'init_declarator_list) in
    Obj.repr(
# 316 "c/clparser.mly"
      ( List.map (ghost _2) _3 )
# 2111 "c/clparser.ml"
               : 'ghost_decl))
; (fun parser_env ->
    Obj.repr(
# 320 "c/clparser.mly"
       ( Cast_misc.noattr (CTint (Unsigned, Char)) )
# 2117 "c/clparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    Obj.repr(
# 321 "c/clparser.mly"
      ( Cast_misc.noattr (CTint (Signed, Int)) )
# 2123 "c/clparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    Obj.repr(
# 322 "c/clparser.mly"
        ( Cast_misc.noattr (CTfloat Float) )
# 2129 "c/clparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    Obj.repr(
# 323 "c/clparser.mly"
         ( Cast_misc.noattr (CTfloat Double) )
# 2135 "c/clparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    Obj.repr(
# 327 "c/clparser.mly"
                 ( [] )
# 2141 "c/clparser.ml"
               : 'parameters))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ne_parameters) in
    Obj.repr(
# 328 "c/clparser.mly"
                ( _1 )
# 2148 "c/clparser.ml"
               : 'parameters))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'parameter) in
    Obj.repr(
# 332 "c/clparser.mly"
            ( [_1] )
# 2155 "c/clparser.ml"
               : 'ne_parameters))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'parameter) in
    let _3 = (peek_val parser_env 0 : 'ne_parameters) in
    Obj.repr(
# 333 "c/clparser.mly"
                                ( _1 :: _3 )
# 2163 "c/clparser.ml"
               : 'ne_parameters))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'logic_type) in
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 337 "c/clparser.mly"
                        ( (_1, _2) )
# 2171 "c/clparser.ml"
               : 'parameter))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'logic_type) in
    let _2 = (peek_val parser_env 2 : string) in
    Obj.repr(
# 338 "c/clparser.mly"
                                        ( (LTarray _1, _2) )
# 2179 "c/clparser.ml"
               : 'parameter))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'init_declarator) in
    Obj.repr(
# 345 "c/clparser.mly"
                          ( [_1] )
# 2186 "c/clparser.ml"
               : 'init_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'init_declarator_list) in
    let _3 = (peek_val parser_env 0 : 'init_declarator) in
    Obj.repr(
# 346 "c/clparser.mly"
                                                     ( _1 @ [_3] )
# 2194 "c/clparser.ml"
               : 'init_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 351 "c/clparser.mly"
            ( let (id,d) = _1 in (id,d, None) )
# 2201 "c/clparser.ml"
               : 'init_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'declarator) in
    let _3 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 353 "c/clparser.mly"
     ( let (id,d) = _1 in (id,d, Some _3) )
# 2209 "c/clparser.ml"
               : 'init_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'direct_declarator) in
    Obj.repr(
# 358 "c/clparser.mly"
                              ( _1 )
# 2216 "c/clparser.ml"
               : 'declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 363 "c/clparser.mly"
            ( _1, Dsimple )
# 2223 "c/clparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_declarator) in
    let _3 = (peek_val parser_env 1 : 'lexpr) in
    Obj.repr(
# 365 "c/clparser.mly"
     ( let id,d = _1 in id, Darray (d, Some _3) )
# 2231 "c/clparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'direct_declarator) in
    Obj.repr(
# 367 "c/clparser.mly"
     ( let id,d = _1 in id, Darray (d, None) )
# 2238 "c/clparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'lexpr) in
    Obj.repr(
# 371 "c/clparser.mly"
                ( Iexpr _1 )
# 2245 "c/clparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'c_initializer_list) in
    Obj.repr(
# 372 "c/clparser.mly"
                                           ( Ilist _2 )
# 2252 "c/clparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'c_initializer_list) in
    Obj.repr(
# 373 "c/clparser.mly"
                                                 ( Ilist _2 )
# 2259 "c/clparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 377 "c/clparser.mly"
                        ( [_1] )
# 2266 "c/clparser.ml"
               : 'c_initializer_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'c_initializer_list) in
    let _3 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 378 "c/clparser.mly"
                                                 ( _1 @ [_3] )
# 2274 "c/clparser.ml"
               : 'c_initializer_list))
(* Entry annot *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
|]
let yytables =
  { actions=yyact;
    transl_const=yytransl_const;
    transl_block=yytransl_block;
    lhs=yylhs;
    len=yylen;
    defred=yydefred;
    dgoto=yydgoto;
    sindex=yysindex;
    rindex=yyrindex;
    gindex=yygindex;
    tablesize=yytablesize;
    table=yytable;
    check=yycheck;
    error_function=parse_error;
    names_const=yynames_const;
    names_block=yynames_block }
let annot (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 1 lexfun lexbuf : Cast.parsed_annot)
;;
